# v0.2.1
- Update Readme

# v0.2.0
- add `rye init` functionality (flags still missing)
- add `rye add` + `rye add --dev` functionality (flags still missing)
- add `rye build` functionality (flags still missing)
- add `rye sync` functionality (flags still missing)
- add General Tab with `Project Home Path`, `rye tools` and `rye toolchains`
- add Config Tab to change rye config (source and default functionality still missing)

# v0.1.0
- initial release
